@@ -4,7 +4,7 @@
 
 ;; Author: Jim Porter
 ;; URL: https://github.com/jimporter/urgrep
-;; Version: 0.5.0
+;; Version: 0.5.1
 ;; Keywords: grep, search
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.0.1") (project "0.3.0"))
 
@@ -1057,7 +1057,8 @@ This function is called from `compilation-filter-hook'."
         (goto-char urgrep--filter-start)
         (catch 'done
           (while (search-forward "\033" end 'limit)
-            (when (eq (char-after) ?\[)
+            (when (or (eq (point) (point-max))
+                      (eq (char-after) ?\[))
               (backward-char)
               (unless (looking-at (rx ansi-any-cseq))
                 ;; This control sequence is incomplete.  Try again next time.
@@ -1114,7 +1115,7 @@ This function is called from `compilation-filter-hook'."
                     (delete-region cseq-begin match-begin))))
                ;; If nothing matched, just proceed forward.
                (t (forward-char))))))
-            (setq urgrep--filter-start (point))))))
+        (setq urgrep--filter-start (point))))))
 
 (defun urgrep-outline-search (&optional bound move backward looking-at)
   "Search for outline headings.  See `outline-search-function'."
@@ -1352,15 +1353,16 @@ future searches."
 
 (defvar-keymap urgrep-minibuffer-map
   :parent minibuffer-local-map
-  "M-s h" #'urgrep-minibuffer-help
-  "M-s r" #'urgrep-toggle-regexp
-  "M-s c" #'urgrep-toggle-case-fold
-  "M-s f" #'urgrep-set-file-wildcards
-  "M-s H" #'urgrep-toggle-search-hidden-files
-  "M-s C" #'urgrep-set-context
-  "M-s B" #'urgrep-set-before-context
-  "M-s A" #'urgrep-set-after-context
-  "M-s t" #'urgrep-set-tool)
+  "M-s" (define-keymap :prefix 'urgrep-minibuffer-options-map
+          "h" #'urgrep-minibuffer-help
+          "r" #'urgrep-toggle-regexp
+          "c" #'urgrep-toggle-case-fold
+          "f" #'urgrep-set-file-wildcards
+          "H" #'urgrep-toggle-search-hidden-files
+          "C" #'urgrep-set-context
+          "B" #'urgrep-set-before-context
+          "A" #'urgrep-set-after-context
+          "t" #'urgrep-set-tool))
 
 (defun urgrep-minibuffer-help ()
   "Describe key bindings for the Urgrep minibuffer."
